@@ -1,19 +1,22 @@
 package org.ovirt.engine.core.bll.aaa;
 
+import javax.inject.Inject;
+
 import org.ovirt.engine.core.bll.QueriesCommandBase;
 import org.ovirt.engine.core.common.queries.VdcQueryParametersBase;
-import org.ovirt.engine.core.dal.dbbroker.DbFacade;
+import org.ovirt.engine.core.dao.DbUserDao;
 
 public class GetAllDbUsersQuery<P extends VdcQueryParametersBase>
         extends QueriesCommandBase<P> {
+    @Inject
+    private DbUserDao dbUserDao;
+
     public GetAllDbUsersQuery(P parameters) {
         super(parameters);
     }
 
     @Override
     protected void executeQueryCommand() {
-        getQueryReturnValue().setReturnValue(
-                DbFacade.getInstance().getDbUserDao()
-                        .getAll(getUserID(), getParameters().isFiltered()));
+        getQueryReturnValue().setReturnValue(dbUserDao.getAll(getUserID(), getParameters().isFiltered()));
     }
 }
