@@ -2,11 +2,11 @@ package org.ovirt.engine.core.bll.network.macpool;
 
 import java.util.List;
 
+import org.ovirt.engine.core.common.utils.ToStringBuilder;
 import org.ovirt.engine.core.compat.Guid;
 
 public class DelegatingMacPoolDecorator implements MacPoolDecorator {
     protected MacPool macPool;
-    protected Guid macPoolId;
 
     public DelegatingMacPoolDecorator() {
     }
@@ -31,11 +31,21 @@ public class DelegatingMacPoolDecorator implements MacPoolDecorator {
         return macPool.addMac(mac);
     }
 
+    @Override
+    public List<String> addMacs(List<String> macs) {
+        return macPool.addMacs(macs);
+    }
+
     @Override
     public void forceAddMac(String mac) {
         macPool.forceAddMac(mac);
     }
 
+    @Override
+    public void forceAddMacs(List<String> macs) {
+        macPool.forceAddMacs(macs);
+    }
+
     @Override
     public boolean isMacInUse(String mac) {
         return macPool.isMacInUse(mac);
@@ -67,7 +77,18 @@ public class DelegatingMacPoolDecorator implements MacPoolDecorator {
     }
 
     @Override
-    public final void setMacPoolId(Guid macPoolId) {
-        this.macPoolId = macPoolId;
+    public Guid getId() {
+        return macPool.getId();
+    }
+
+    @Override
+    public final String toString() {
+        ToStringBuilder result = ToStringBuilder.forInstance(this);
+
+        if (macPool != null) {
+            result.append("macPool", macPool.toString());
+        }
+
+        return result.build();
     }
 }
