@@ -6,7 +6,6 @@ import org.apache.commons.lang.StringUtils;
 import org.ovirt.engine.core.bll.ValidationResult;
 import org.ovirt.engine.core.bll.hostedengine.HostedEngineHelper;
 import org.ovirt.engine.core.common.action.VdsOperationActionParameters.AuthenticationMethod;
-import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.businessentities.ExternalComputeResource;
 import org.ovirt.engine.core.common.businessentities.ExternalHostGroup;
 import org.ovirt.engine.core.common.businessentities.HostedEngineDeployConfiguration;
@@ -17,7 +16,6 @@ import org.ovirt.engine.core.common.config.Config;
 import org.ovirt.engine.core.common.config.ConfigValues;
 import org.ovirt.engine.core.common.errors.EngineMessage;
 import org.ovirt.engine.core.common.utils.ValidationUtils;
-import org.ovirt.engine.core.compat.Version;
 import org.ovirt.engine.core.dao.ClusterDao;
 import org.ovirt.engine.core.dao.StoragePoolDao;
 import org.ovirt.engine.core.dao.VdsDao;
@@ -174,14 +172,7 @@ public class HostValidator {
         if (heConfig == null) {
             return ValidationResult.VALID;
         }
-        final Cluster cluster = clusterDao.get(host.getClusterId());
-        if (cluster.getCompatibilityVersion().less(Version.v4_0)
-                && heConfig.getDeployAction() != HostedEngineDeployConfiguration.Action.NONE) {
-            return new ValidationResult(
-                    EngineMessage.ACTION_TYPE_FAILED_HOSTED_ENGINE_DEPLOYMENT_UNSUPPORTED,
-                    "$deployAction " + heConfig.getDeployAction().name().toLowerCase(),
-                    "$clusterLevel " + cluster.getCompatibilityVersion());
-        }
+
         return ValidationResult.failWith(EngineMessage.ACTION_TYPE_FAILED_UNMANAGED_HOSTED_ENGINE)
                 .when(heConfig.getDeployAction() == HostedEngineDeployConfiguration.Action.DEPLOY
                         && !hostedEngineHelper.isVmManaged());
