@@ -1,6 +1,10 @@
 package org.ovirt.engine.api.restapi.resource;
 
+import javax.ws.rs.core.Response;
+
 import org.ovirt.engine.api.model.StorageConnection;
+import org.ovirt.engine.core.common.action.EditIscsiBondParameters;
+import org.ovirt.engine.core.common.action.VdcActionType;
 import org.ovirt.engine.core.common.businessentities.IscsiBond;
 import org.ovirt.engine.core.common.businessentities.StorageServerConnections;
 import org.ovirt.engine.core.common.queries.StorageServerConnectionQueryParametersBase;
@@ -33,4 +37,12 @@ public class BackendIscsiBondStorageConnectionResource extends BackendStorageSer
         }
         return addLinks(map(entity));
     }
+
+    @Override
+    public Response remove() {
+        get();
+        IscsiBond iscsiBond = parent.getIscsiBond();
+        iscsiBond.getStorageConnectionIds().remove(id);
+        return performAction(VdcActionType.EditIscsiBond, new EditIscsiBondParameters(iscsiBond));
+    }
 }
