@@ -1,10 +1,9 @@
 package org.ovirt.engine.ui.webadmin.section.main.presenter.popup.pool;
 
-import com.google.gwt.event.shared.EventBus;
-import com.google.inject.Inject;
-import org.ovirt.engine.ui.common.CommonApplicationMessages;
 import org.ovirt.engine.ui.common.system.ClientStorage;
 import org.ovirt.engine.ui.common.widget.popup.AbstractVmBasedPopupPresenterWidget;
+import com.google.gwt.event.shared.EventBus;
+import com.google.inject.Inject;
 
 public class PoolNewPopupPresenterWidget extends BasePoolPopupPresenterWidget<PoolNewPopupPresenterWidget.ViewDef> {
     public interface ViewDef extends AbstractVmBasedPopupPresenterWidget.ViewDef {
@@ -12,8 +11,8 @@ public class PoolNewPopupPresenterWidget extends BasePoolPopupPresenterWidget<Po
     }
 
     @Inject
-    public PoolNewPopupPresenterWidget(EventBus eventBus, ViewDef view, CommonApplicationMessages messages, ClientStorage clientStorage) {
-        super(eventBus, view, messages, clientStorage);
+    public PoolNewPopupPresenterWidget(EventBus eventBus, ViewDef view, ClientStorage clientStorage) {
+        super(eventBus, view, clientStorage);
     }
 
 }
